@@ -1,13 +1,13 @@
 package App::rmhere;
 
-our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::chdir;
 
@@ -168,7 +168,7 @@ App::rmhere - Delete files in current directory
 
 =head1 VERSION
 
-This document describes version 0.04 of App::rmhere (from Perl distribution App-rmhere), released on 2015-01-22.
+This document describes version 0.05 of App::rmhere (from Perl distribution App-rmhere), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
